@@ -2,9 +2,9 @@ import sys
 
 from toggl import cli
 
-TOGGL_URL = "https://api.track.toggl.com/api/v8"
-REPORTS_URL = "https://api.track.toggl.com/reports/api/v2"
-WEB_CLIENT_ADDRESS = "https://track.toggl.com/"
+TOGGL_URL = "https://www.toggl.com/api/v8"
+REPORTS_URL = "https://toggl.com/reports/api/v2"
+WEB_CLIENT_ADDRESS = "https://www.toggl.com/app/"
 
 
 def main(args=None):
